@@ -6,7 +6,7 @@
 --	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 --	Author: Jan Wieck, Afilias USA INC.
 --
--- $Id: slony1_funcs.v81.sql,v 1.1.2.3 2009-08-17 17:39:57 devrim Exp $
+-- 
 -- ----------------------------------------------------------------------
 
 -- ----------------------------------------------------------------------
@@ -43,7 +43,7 @@ begin
 	-- Try using truncate to empty the table and fallback to
 	-- delete on error.
 	-- ----
-	execute ''truncate '' || @NAMESPACE@.slon_quote_input(v_tab_fqname);
+	perform @NAMESPACE@.TruncateOnlyTable(v_tab_fqname);
 	raise notice ''truncate of % succeeded'', v_tab_fqname;
 
 	-- ----
@@ -131,3 +131,18 @@ end
 
 comment on function @NAMESPACE@.make_function_strict (text, text) is
 'Equivalent to 8.1+ ALTER FUNCTION ... STRICT';
+
+
+
+
+create or replace function @NAMESPACE@.TruncateOnlyTable ( name) returns void as
+$$
+begin
+	execute 'truncate '|| @NAMESPACE@.slon_quote_input($1);
+end;
+$$
+LANGUAGE plpgsql;
+
+
+comment on function @NAMESPACE@.TruncateOnlyTable(name) is
+'Calls TRUNCATE with out specifying ONLY, syntax supported in versions 8.3 and below';
\ No newline at end of file
