@@ -3,10 +3,10 @@
  *
  *	Functions maintaining the in-memory configuration information
  *
- *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+ *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: runtime_config.c,v 1.27 2005/11/22 05:11:59 wieck Exp $
+ *	
  *-------------------------------------------------------------------------
  */
 
@@ -25,7 +25,6 @@
 
 #include "libpq-fe.h"
 #include "c.h"
-
 #include "slon.h"
 
 
@@ -276,7 +275,7 @@ rtcfg_disableNode(int no_id)
 		rtcfg_unlock();
 
 		slon_log(SLON_FATAL,
-				 "enableNode: unknown node ID %d\n", no_id);
+				 "disableNode: unknown node ID %d\n", no_id);
 		slon_retry();
 		return;
 	}
