@@ -3,10 +3,10 @@
  *
  *	Definitions for slonik
  *
- *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
+ *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: slonik.h,v 1.27 2006/03/08 18:29:10 darcyb Exp $
+ *	
  *-------------------------------------------------------------------------
  */
 
@@ -49,6 +49,8 @@ typedef struct SlonikStmt_ddl_script_s SlonikStmt_ddl_script;
 typedef struct SlonikStmt_update_functions_s SlonikStmt_update_functions;
 typedef struct SlonikStmt_wait_event_s SlonikStmt_wait_event;
 typedef struct SlonikStmt_switch_log_s SlonikStmt_switch_log;
+typedef struct SlonikStmt_sync_s SlonikStmt_sync;
+typedef struct SlonikStmt_sleep_s SlonikStmt_sleep;
 
 typedef enum
 {
@@ -87,7 +89,9 @@ typedef enum
 	STMT_UPDATE_FUNCTIONS,
 	STMT_WAIT_EVENT,
 	STMT_SWITCH_LOG,
-	STMT_ERROR
+	STMT_ERROR,
+	STMT_SYNC,
+	STMT_SLEEP
 }	Slonik_stmttype;
 
 struct SlonikScript_s
@@ -431,6 +435,19 @@ struct SlonikStmt_switch_log_s
 };
 
 
+struct SlonikStmt_sync_s
+{
+	SlonikStmt	hdr;
+	int			no_id;
+};
+
+struct SlonikStmt_sleep_s
+{
+	SlonikStmt	hdr;
+	int			num_secs;
+};
+
+
 
 
 extern SlonikScript *parser_script;
@@ -553,6 +570,8 @@ extern int	slonik_ddl_script(SlonikStmt_ddl_script * stmt);
 extern int	slonik_update_functions(SlonikStmt_update_functions * stmt);
 extern int	slonik_wait_event(SlonikStmt_wait_event * stmt);
 extern int	slonik_switch_log(SlonikStmt_switch_log * stmt);
+extern int	slonik_sync(SlonikStmt_sync * stmt);
+extern int	slonik_sleep(SlonikStmt_sleep * stmt);
 
 extern int	slon_scanint64(char *str, int64 * result);
 
