@@ -1,9 +1,10 @@
 #!@@PERL@@
-# $Id: slonik_execute_script.pl,v 1.1.2.1 2007-03-13 15:35:43 cbbrowne Exp $
+# 
 # Author: Christopher Browne
-# Copyright 2004 Afilias Canada
+# Copyright 2004-2009 Afilias Canada
 
 use Getopt::Long;
+use File::Temp qw(tempfile);
 
 # Defaults
 $CONFIG_FILE = '@@SYSCONFDIR@@/slon_tools.conf';
@@ -14,6 +15,10 @@ $SCRIPT_ARG  = "";
 # the get_set function.
 $node = 0;
 
+# temp file variable for script handling
+my $filename = '';
+my $fh       = undef;
+
 # Read command-line options
 GetOptions("config=s" => \$CONFIG_FILE,
 	   "help"     => \$SHOW_USAGE,
@@ -66,13 +71,11 @@ if ($file) {
 	print STDERR "SQL script path needs to be a full path, e.g. /tmp/my_script.sql\n\n";
 	die $USAGE;
     }
+    $filename = $file
 }
 elsif ($SCRIPT_ARG) {
     # Put the script into a file
-    $file = "/tmp/execute_script.sql.$$";
-    my $fh;
-    $filename = $file
-    open $fh, ">", $file;
+    ($fh, $filename) = tempfile();
     print $fh $SCRIPT_ARG;
     close $fh;
 }
@@ -81,13 +84,13 @@ else {
     die $USAGE;
 }
 
-my $FILE="/tmp/gensql.$$";
-open(SLONIK, ">", $FILE);
-print SLONIK genheader();
-print SLONIK "  execute script (\n";
-print SLONIK "    set id = $set,\n";
-print SLONIK "    filename = '$file',\n";
-print SLONIK "    event node = $node\n";
-print SLONIK "  );\n";
-close SLONIK;
-run_slonik_script($FILE);
+my $slonik = '';
+
+$slonik .= genheader();
+$slonik .= "  execute script (\n";
+$slonik .= "    set id = $set,\n";
+$slonik .= "    filename = '$filename',\n";
+$slonik .= "    event node = $node\n";
+$slonik .= "  );\n";
+
+run_slonik_script($slonik, 'EXECUTE SCRIPT');
