@@ -1,7 +1,7 @@
 #!/usr/bin/perl
-# $Id: slonik_restart_node.pl,v 1.1 2005-05-31 16:11:05 cbbrowne Exp $
+# 
 # Author: Christopher Browne
-# Copyright 2004 Afilias Canada
+# Copyright 2004-2009 Afilias Canada
 
 use Getopt::Long;
 
@@ -47,11 +47,10 @@ else {
 
 die $USAGE unless scalar @nodes;
 
-my $FILE="/tmp/restart.$$";
-open(SLONIK, ">", $FILE);
-print SLONIK genheader();
+my $slonik = '';
+$slonik .= genheader();
 foreach my $node (@nodes) {
-    print SLONIK "  restart node $node;\n";
+    $slonik .= "  restart node $node;\n";
 }
-close SLONIK;
-run_slonik_script($FILE);
+
+run_slonik_script($slonik, 'RESTART NODE');
